Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file configuration_intf.ml
123456789101112131415161718192021222324252627282930313233343536373839404142434445464748495051525354555657585960616263646566676869707172737475767778798081828384858687888990919293949596979899100101102103104105106107108109110111open!Coreopen!AsyncmoduletypeS=sig(** Some configuration that a program wants *)typet[@@derivingof_sexp](** The environment variable used to retrieve configuration overrides *)valenvironment_variable:string(** What to display when the environment variable is malformed, in addition
to some helpful information *)valdocumentation:string(** Allow extra fields to be present in the configuration sexp deserializer.
Most users will want this to be true, as it is unlikely the configuration
will always be the same type, and most types are not versioned. *)valallow_extra_fields:boolendmoduletypeOverridable=sigincludeS(** A mechanism for instructing a different configuration than the default
be loaded by providing a different environment value than a [t].
This is used, for example, to modify a particular part of a [t] without
having to specify all of it.
*)moduleEnvironment_override:sigtypet[@@derivingof_sexp]end(** The environment requested that the config be determined by
[Environment_override]. The default is provided to this function. *)valfrom_override:default_config:tOr_error.t->Environment_override.t->tend(** The default configuration is loaded from a file on disk. *)moduleLoad_from_disk=struct(** The default path, and loading function are computed synchronously *)moduletypeBlocking=sigtypetincludeSwithtypet:=t(** The default configuration *)valdefault_path:unit->string(** How to load a configuration from disk. This will be used in conjunction
with [default_path] if no override is provided. *)valload_from_disk:path:string->tendmoduletypeBlocking_overridable=sigincludeBlockingincludeOverridablewithtypet:=tend(** The default path, and loading function are computed asynchronously *)moduletypeAsync=sigtypetincludeSwithtypet:=t(** The default configuration *)valdefault_path:unit->stringDeferred.t(** How to load a configuration from disk. This will be used in conjunction
with [default_path] if no override is provided. *)valload_from_disk:path:string->tDeferred.tendmoduletypeAsync_overridable=sigincludeAsyncincludeOverridablewithtypet:=tendend(** The default configuration is computed, or embedded in the library *)moduleEmbedded_in_library=struct(** The default configuration is computed synchronously *)moduletypeBlocking=sigtypetincludeSwithtypet:=t(** Compute the default configuration *)valdefault:unit->tendmoduletypeBlocking_overridable=sigincludeBlockingincludeOverridablewithtypet:=tend(** The default configuration is computed asynchronously *)moduletypeAsync=sigtypetincludeSwithtypet:=t(** Compute the default configuration *)valdefault:unit->tDeferred.tendmoduletypeAsync_overridable=sigincludeAsyncincludeOverridablewithtypet:=tendend